@@ -1,7 +1,8 @@
-from .model import IpAPIResponse, MembersAPIResponse, PlayerInfoRodinaAPIResponse, PlayerInfoArizonaAPIResponse, \
-    CreatedFindTaskAPIResponse, \
+import time
+
+from .model import IpAPIResponse, MembersAPIResponse, PlayerInfoAPIResponse, CreatedFindTaskAPIResponse, \
     ServerStatusAPIResponse, RatingAPIResponse, CheckRPUsernameAPIResponse, GenerateRPUsernameAPIResponse, \
-    PlayerInfoNotFound
+    PlayerInfoNotFound, PlayerOnlineAPIResponse
 
 from .api import get, post
 from typing import Literal
@@ -10,8 +11,8 @@ from pydantic import parse_obj_as, ValidationError
 
 
 class VprikolAPI:
-    def __init__(self, token: str, base_url: str = 'https://api.vprikol.ru/'):
-        if len(token) < 1:
+    def __init__(self, token: str, base_url: str = 'https://api.szx.su/'):
+        if not token.startswith('eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.'):
             raise Exception('Токен передан неправильно.')
         self.headers = {'Authorization': f'Bearer {token}'}
         self.base_url = base_url
@@ -49,9 +50,7 @@ class VprikolAPI:
 
         return response
 
-    async def get_player_information(self, server_id: int, nickname: str) -> PlayerInfoRodinaAPIResponse \
-                                                                             | PlayerInfoArizonaAPIResponse \
-                                                                             | PlayerInfoNotFound:
+    async def get_player_information(self, server_id: int, nickname: str) -> PlayerInfoAPIResponse | PlayerInfoNotFound:
         task = await post(url=f'{self.base_url}find/createTask', headers=self.headers,
                           params={'server': server_id, 'nick': nickname})
         if not task.success:
@@ -63,18 +62,18 @@ class VprikolAPI:
                                params={'request_id': task.request_id})
 
             if not result.success and result.error.error_code and result.error.error_code == 425:
-                await asyncio.sleep(1)
+                await asyncio.sleep(0.5)
                 continue
 
             if result.error and result.error.error_code == 422:
                 return PlayerInfoNotFound(**result.error.dict())
 
             try:
-                return PlayerInfoArizonaAPIResponse(**result.data)
+                return PlayerInfoAPIResponse(**result.data)
             except ValidationError:
-                return PlayerInfoArizonaAPIResponse(**result.data)
+                return PlayerInfoAPIResponse(**result.data)
 
-    async def get_server_status(self, server_id: int | None = None) -> list[ServerStatusAPIResponse]:
+    async def get_server_status(self, server_id: int | None = None) -> list[ServerStatusAPIResponse] | ServerStatusAPIResponse:
         if server_id:
             params = {'server': server_id}
         else:
@@ -89,12 +88,10 @@ class VprikolAPI:
         if isinstance(result.data, list):
             return parse_obj_as(list[ServerStatusAPIResponse], result.data)
 
-    async def get_rating(self, server_id: int, first_type: Literal[1, 2, 3],
-                         second_type: Literal[1, 2, 3] | None = None) -> RatingAPIResponse:
-        if second_type:
-            params = {'type': first_type, 'subtype': second_type, 'server': server_id}
-        else:
-            params = {'type': first_type, 'server': server_id}
+        return ServerStatusAPIResponse(**result.data)
+
+    async def get_rating(self, server_id: int, rating_type: Literal[1, 2, 3]) -> RatingAPIResponse:
+        params = {'type': rating_type, 'server': server_id}
 
         result = await get(url=f'{self.base_url}rating', headers=self.headers,
                            params=params)
@@ -104,13 +101,12 @@ class VprikolAPI:
 
         return RatingAPIResponse(**result.data)
 
-    async def check_rp_nickname(self, nickname: str) -> CheckRPUsernameAPIResponse:
+    async def check_rp_nickname(self, nickname: str, ai: bool = False) -> CheckRPUsernameAPIResponse:
         result = await get(url=f'{self.base_url}checkrp', headers=self.headers,
-                           params={'nick': nickname})
+                           params={'nick': nickname, 'ai': int(ai)})
 
         if not result.success:
             raise Exception(result.error)
-
         return CheckRPUsernameAPIResponse(**result.data)
 
     async def generate_rp_nickname(self, gender: Literal['male', 'female'], nation: Literal[
@@ -122,3 +118,14 @@ class VprikolAPI:
             raise Exception(result.error)
 
         return GenerateRPUsernameAPIResponse(**result.data)
+
+    async def get_player_online(self, nickname: str, server_id: int, count: int = 100,
+                                offset: int = 0, date: int = int(time.time())) -> PlayerOnlineAPIResponse:
+        result = await get(url=f'{self.base_url}online', headers=self.headers,
+                           params={'nickname': nickname, 'count': count, 'offset': offset, 'server_id': server_id,
+                                   'filter_by_date': date})
+
+        if not result.success:
+            raise Exception(result.error)
+
+        return PlayerOnlineAPIResponse(**result.data)
